==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/nl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Bijwerken meldingen",
    "Could not start updater, please try the manual update" : "Kon de updater niet starten, probeer alsjeblieft de handmatige update",
    "{version} is available. Get more information on how to update." : "{version} is beschikbaar. Meer informatie over het bijwerken.",
    "Channel updated" : "Kanaal bijgewerkt",
    "The update server could not be reached since %d days to check for new updates." : "De updateserver kon sinds %d dagen niet meer worden bereikt om op updates te controleren.",
    "Please check the Nextcloud and server log files for errors." : "Controleer de Nextcloud en server logbestanden op fouten.",
    "Update to %1$s is available." : "Update naar %1$s is beschikbaar.",
    "Update for %1$s to version %2$s is available." : "Update voor %1$s naar versie %2$s is beschikbaar.",
    "Update for {app} to version %s is available." : "Update voor {app} naar versie %s is beschikbaar.",
    "Update notification" : "Update melding",
    "A new version is available: %s" : "Er is een nieuwe versie beschikbaar: %s",
    "Open updater" : "Open updater",
    "Download now" : "Download nu",
    "Your version is up to date." : "Je versie is up to date.",
    "Checked on %s" : "Gecontroleerd op %s",
    "Update channel:" : "Bijwerkkanaal:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Je kunt altijd updaten naar een nieuwere versie of experimenteel kanaal. Maar terug naar een oudere versie of een stabieler kanaal is niet mogelijk.",
    "Notify members of the following groups about available updates:" : "Geef een melding over beschikbare updates aan leden van de volgende groepen:",
    "Only notification for app updates are available." : "Er zijn alleen meldingen voor apps beschikbaar.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Het geselecteerde updatekanaal maakt overbodig om serverspecifieke meldingen apart te genereren.",
    "The selected update channel does not support updates of the server." : "Het geselecteerde updatekanaal ondersteunt geen updates voor de server."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/nl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Bijwerken meldingen",
    "Could not start updater, please try the manual update" : "Kon de updater niet starten, probeer alsjeblieft de handmatige update",
    "{version} is available. Get more information on how to update." : "{version} is beschikbaar. Meer informatie over het bijwerken.",
    "Channel updated" : "Kanaal bijgewerkt",
    "The update server could not be reached since %d days to check for new updates." : "De updateserver kon sinds %d dagen niet meer worden bereikt om op updates te controleren.",
    "Please check the Nextcloud and server log files for errors." : "Controleer de Nextcloud en server logbestanden op fouten.",
    "Update to %1$s is available." : "Update naar %1$s is beschikbaar.",
    "Update for %1$s to version %2$s is available." : "Update voor %1$s naar versie %2$s is beschikbaar.",
    "Update for {app} to version %s is available." : "Update voor {app} naar versie %s is beschikbaar.",
    "Update notification" : "Update melding",
    "A new version is available: %s" : "Er is een nieuwe versie beschikbaar: %s",
    "Open updater" : "Open updater",
    "Download now" : "Download nu",
    "Your version is up to date." : "Je versie is up to date.",
    "Checked on %s" : "Gecontroleerd op %s",
    "Update channel:" : "Bijwerkkanaal:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Je kunt altijd updaten naar een nieuwere versie of experimenteel kanaal. Maar terug naar een oudere versie of een stabieler kanaal is niet mogelijk.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Houd er rekening mee dat het enige tijd kan duren voordat na een nieuwe versie hier verschijnt. We verspreiden nieuwe versies over de tijd aan onze gebruikers en soms slaan we een versie over als er problemen zijn gevonden.",
    "Notify members of the following groups about available updates:" : "Geef een melding over beschikbare updates aan leden van de volgende groepen:",
    "Only notification for app updates are available." : "Er zijn alleen meldingen voor apps beschikbaar.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Het geselecteerde updatekanaal maakt overbodig om serverspecifieke meldingen apart te genereren.",
    "The selected update channel does not support updates of the server." : "Het geselecteerde updatekanaal ondersteunt geen updates voor de server."
},
"nplurals=2; plural=(n != 1);");
